icsemantic.catalog.tests

Package platecom :: Package ontocatalog :: Package tests |
[hide private]
[frames] | no frames]

# Package tests

source code

Automated unit, functional and integration tests for OntoCatalog.

Submodules | [hide private]
icsemantic.catalog.tests.base: Test setup for unit, integration and functional tests. icsemantic.catalog.tests.test_functional: Functional tests for OntoCatalog. icsemantic.catalog.tests.test_indexes: Test the catalog indexes added by OntoCatalog. icsemantic.catalog.tests.test_setup: Test OntoCatalog setup on installation.